# tslumd

Client and Server for TSLUMD Tally Protocols

# License

Copyright (c) 2021 Matthew Reid <matt@nomadic-recording.com>

tslumd is licensed under the MIT license, please see LICENSE file for details.
